@@ -13,8 +13,9 @@ use warnings;
 use strict;
 
 use Class::XSAccessor accessors => {
-    _ignore  => '_ignore',
-    _speller => '_speller',
+    _ignore  => '_ignore',      # list of words to ignore
+    _plugin  => '_plugin',      # ref to spellecheck plugin
+    _speller => '_speller',     # real text::aspell object
 };
 use Text::Aspell;
 
@@ -22,17 +23,19 @@ use Text::Aspell;
 # -- constructor
 
 sub new {
-    my ($class) = @_;
+    my ($class, $plugin) = @_;
 
     my $self = bless {
         _ignore => {},
+        _plugin => $plugin,
     }, $class;
 
     # create speller object
     my $speller = Text::Aspell->new;
+    my $config  = $plugin->config;
     # TODO: configurable later
-    $speller->set_option('sug-mode', 'fast');
-    $speller->set_option('lang','en_US');
+    $speller->set_option('sug-mode', 'normal');
+    $speller->set_option('lang', $config->{dictionary});
     $self->_speller( $speller );
 
     return $self;
@@ -67,6 +70,15 @@ sub check {
     return;
 }
 
+
+sub dictionaries {
+    my ($self) = @_;
+    return
+        grep { $_=~ /^\w+$/ }
+        map  { $_->{name} }
+        $self->_speller->dictionary_info;
+}
+
 sub ignore {
     my ($self, $word) = @_;
     $self->_ignore->{$word} = 1;
@@ -123,6 +135,14 @@ the text (position of the start of the faulty word).
 Tell engine to ignore C<$word> for rest of the spell check.
 
 
+=item * my @dictionaries = $engine->dictionaries;
+
+Return a (reduced) list of dictionaries installed with aspell. The
+names returned are the dictionary locale names (eg C<en_US>). Note
+that only plain locales are reported, the variations coming with
+aspell are stripped.
+
+
 =item * my @suggestions = $engine->suggestions( $word );
 
 Return suggestions for C<$word>.
